
/*******************************************************************************
* Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
*
* This file is part of PAPPSOms-tools.
*
*     PAPPSOms-tools is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     PAPPSOms-tools is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with PAPPSOms-tools.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and implementation
******************************************************************************/

#ifndef READSPECTRUM_H
#define READSPECTRUM_H

#include <QString>
#include <pappsomspp/spectrum/qualifiedspectrum.h>
#include <pappsomspp/xicextractor/msrunxic.h>
#include <map>
#include "../core/msrun.h"

pappso::Spectrum readSpectrum(const QString & filename, unsigned int scan_num,unsigned int & precursor_charge_state);


namespace pwiz {
namespace msdata {
class MSDataFile;
}
}
//MzFormat getPwizMSDataFileFormat(pwiz::msdata::MSDataFile * p_ms_data_file);

class SpectrumStore {
public:
    static pappso::SpectrumSp getSpectrumSpFromMsRunSp(MsRun * p_msrun, unsigned int scan_num);
    static std::vector<pappso::MsRunXicSp> getXicSpFromMsRunSp(MsRun * p_msrun, const std::vector<pappso::MassRange> & mass_range_list, pappso::XicExtractMethod method);
    /** @brief try to find MS run statistics
     */
    static void checkMsRunStatistics(MsRun *);
private:
    static const QString findMzFile(const QString &filename);
    static pwiz::msdata::MSDataFile * findPwizMSDataFile(MsRun * p_msrun) ;
    static pwiz::msdata::MSDataFile * findPwizMSDataFile(const MsRun * p_msrun) ;
private:
    static std::map<const MsRun *, pwiz::msdata::MSDataFile *> _map_msrun_msdatafile;
};
#endif // READSPECTRUM_H
